package com.microsoft.office.onenote.ui

import android.content.Context
import android.support.v7.widget.AppCompatEditText
import android.util.AttributeSet
import android.view.inputmethod.EditorInfo
import android.view.inputmethod.InputConnection
import android.view.inputmethod.InputMethodManager

/**
 * EditText class extended to show/hide soft keyboard on EditText as required
 */

class SearchBarEditText : AppCompatEditText {
    private var mHasPendingShowSoftInputRequest = false

    constructor(context: Context) : super(context)
    constructor(context: Context, attrs: AttributeSet) : super(context, attrs)
    constructor(context: Context, attrs: AttributeSet, defStyleAttr: Int) : super(context, attrs, defStyleAttr)

    override fun onCreateInputConnection(outAttrs: EditorInfo): InputConnection {
        val ic = super.onCreateInputConnection(outAttrs)
        showSoftInputIfRequired()
        return ic
    }

    /*
     * show/ hide soft keyboard on the EditText
     */
    fun setImeVisibility(visible: Boolean) {
        val imm = (context.getSystemService(Context.INPUT_METHOD_SERVICE) as? InputMethodManager) ?: return

        if (!visible) {
            mHasPendingShowSoftInputRequest = false
            imm.hideSoftInputFromWindow(windowToken, 0)
            return
        }

        if (imm.isActive(this)) {
            imm.showSoftInput(this, 0)
            mHasPendingShowSoftInputRequest = false
            return
        }

        mHasPendingShowSoftInputRequest = true
    }

    private fun showSoftInputIfRequired() {
        if (mHasPendingShowSoftInputRequest) {
            val imm = context.getSystemService(Context.INPUT_METHOD_SERVICE) as? InputMethodManager ?: return

            imm.showSoftInput(this, 0)
            mHasPendingShowSoftInputRequest = false
        }
    }

}
