package com.microsoft.office.onenote.ui.signin

import android.content.Context
import android.content.DialogInterface
import android.content.Intent
import android.net.Uri

import com.microsoft.office.onenote.commonlibraries.telemetry.ONMTelemetryWrapper
import com.microsoft.office.onenote.ui.dialogs.ONMAlertDialogBuilder
import com.microsoft.office.onenote.ui.utils.ONMAccountUtils
import com.microsoft.office.onenote.ui.utils.ONMSharedPreferences
import com.microsoft.office.onenote.utils.ONMFeatureGateUtils
import com.microsoft.office.onenotelib.R;

import java.util.HashMap


class ONMEmailAccrualDialog internal constructor(context: Context) {
    private var emailAccrualDialog: ONMAlertDialogBuilder

    init {
        emailAccrualDialog = ONMAlertDialogBuilder(context)

        emailAccrualDialog
                .setTitle(R.string.email_accrual_title)
                .setMessage(R.string.email_accrual_description)
                .setPositiveButton(R.string.fix_email_accrual_button, DialogInterface.OnClickListener { dialog, which ->
                    val payload = HashMap<String, String>()
                    payload.put(ONMTelemetryWrapper.ACTION, ONMTelemetryWrapper.DialogAction.PositiveButtonClicked.name)
                    ONMTelemetryWrapper.recordCriticalEvent(ONMTelemetryWrapper.MARKERS.EmailAccrualEvent, ONMTelemetryWrapper.Categories.OneNoteNavigation, payload)

                    ONMEmailAccrualTask(object : ONMEmailAccrualTask.ONMEmailAccrualCallback {
                        override fun onTaskCompleted(userEnteredValidEmailAddress: Boolean) {
                            if (userEnteredValidEmailAddress) {
                                ONMSharedPreferences.setShowEmailAccrualScreen(context, false)
                            }

                            val resultPayload = HashMap<String, String>()
                            resultPayload.put(ONMTelemetryWrapper.EMAIL_ACCRUAL_RESULT, userEnteredValidEmailAddress.toString());
                            ONMTelemetryWrapper.recordCriticalEvent(ONMTelemetryWrapper.MARKERS.EmailAccrualEvent, ONMTelemetryWrapper.Categories.OneNoteNavigation, resultPayload)
                        }
                    })
                    .execute(ONMAccountUtils.getDefaultLiveAccountId())
                })
                .setNegativeButton(R.string.button_learn_more, DialogInterface.OnClickListener { dialog, which ->
                    val learnMoreUrl = "https://aka.ms/onphoneauthissue"
                    val learnMoreIntent = Intent(Intent.ACTION_VIEW)
                    learnMoreIntent.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK)
                    learnMoreIntent.data = Uri.parse(learnMoreUrl)
                    context.startActivity(learnMoreIntent)
                    val payload = HashMap<String, String>()
                    payload.put(ONMTelemetryWrapper.ACTION, ONMTelemetryWrapper.DialogAction.NegativeButtonClicked.name)
                    ONMTelemetryWrapper.recordCriticalEvent(ONMTelemetryWrapper.MARKERS.EmailAccrualEvent, ONMTelemetryWrapper.Categories.OneNoteNavigation, payload)
                })
    }

    fun show() {
        emailAccrualDialog.show()
    }

}