package com.microsoft.office.onenote.ui.signin

import android.os.AsyncTask

import com.microsoft.office.identity.IdentityLiblet
import com.microsoft.office.onenote.commonlibraries.telemetry.ONMTelemetryWrapper
import com.microsoft.office.onenote.ui.utils.ONMCommonUtils
import com.microsoft.office.onenote.utils.ONMStringUtils
import java.util.HashMap

/**
 * AsyncTask to show email accrual screen to user
 * should only be used with live accounts
 * @param : usercid, can be obtained by calling ONMAccountUtils.getDefaultLiveAccountId()
 */
class ONMEmailAccrualTask(listener: ONMEmailAccrualCallback) : AsyncTask<String, Void, Void>(), IdentityLiblet.IOnSignInCompleteListener {
    private val listener: ONMEmailAccrualCallback
    private val MSAServiceUrl = "ssl.live.com"
    private val MSAPolicy = "MBI_SSL"

    init {
        this.listener = listener
    }

    override fun doInBackground(vararg params: String): Void? {
        val usercid = params[0]
        ONMCommonUtils.devApkAssert(!ONMStringUtils.isNullOrEmpty(usercid), "usercid should not be null or empty")

        IdentityLiblet.GetInstance().SignInMSAUser(
                "",
                usercid /*cid*/,
                MSAPolicy,
                MSAServiceUrl,
                false, /*signUp*/
                true, /*showUI*/
                false, /*UseCache*/
                this@ONMEmailAccrualTask)

        return null
    }

    override fun onSuccess(userId: String, result: String) {
        listener.onTaskCompleted(true /*userEnteredValidEmailAddress*/)
    }

    override fun onError(errorCode: Int) {
        val payload = HashMap<String, String>()
        payload.put(ONMTelemetryWrapper.ERROR_CODE, errorCode.toString());
        ONMTelemetryWrapper.recordCriticalEvent(ONMTelemetryWrapper.MARKERS.EmailAccrualEvent, ONMTelemetryWrapper.Categories.OneNoteSignIn, payload)
        listener.onTaskCompleted(false /*userEnteredValidEmailAddress*/)
    }

    interface ONMEmailAccrualCallback {
        //will inform the caller is the user has successfully entered a email or not
        fun onTaskCompleted(userEnteredValidEmailAddress: Boolean)
    }
}
